from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="ConfirmForgotPasswordRequest")


@attr.s(auto_attribs=True)
class ConfirmForgotPasswordRequest:
    """
    Attributes:
        email (str):
        confirmation_code (str):
        new_password (str):
    """

    email: str
    confirmation_code: str
    new_password: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        email = self.email
        confirmation_code = self.confirmation_code
        new_password = self.new_password

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "email": email,
                "confirmationCode": confirmation_code,
                "newPassword": new_password,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        email = d.pop("email")

        confirmation_code = d.pop("confirmationCode")

        new_password = d.pop("newPassword")

        confirm_forgot_password_request = cls(
            email=email,
            confirmation_code=confirmation_code,
            new_password=new_password,
        )

        confirm_forgot_password_request.additional_properties = d
        return confirm_forgot_password_request

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
