from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="DeviceProvisioningRequest")


@attr.s(auto_attribs=True)
class DeviceProvisioningRequest:
    """
    Attributes:
        provisioning_token (str):
        public_key (str):
    """

    provisioning_token: str
    public_key: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        provisioning_token = self.provisioning_token
        public_key = self.public_key

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "provisioningToken": provisioning_token,
                "publicKey": public_key,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        provisioning_token = d.pop("provisioningToken")

        public_key = d.pop("publicKey")

        device_provisioning_request = cls(
            provisioning_token=provisioning_token,
            public_key=public_key,
        )

        device_provisioning_request.additional_properties = d
        return device_provisioning_request

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
